@@ -1,26 +1,29 @@
 import os
 import copy
 import base64
-import requests
 import tempfile
 import pkgutil
+import hashlib
 import insights.client.apps.ansible
 from logging import getLogger
-from distutils.version import LooseVersion
-from insights.client.utilities import get_version_info
 from insights.client.apps.ansible.playbook_verifier.contrib import gnupg
-from insights.client.apps.ansible.playbook_verifier.contrib import oyaml as yaml
+from insights.client.apps.ansible.playbook_verifier.contrib.ruamel_yaml.ruamel import yaml
 from insights.client.constants import InsightsConstants as constants
 
 __all__ = ("loadPlaybookYaml", "verify", "PlaybookVerificationError")
 
 SIGKEY = 'insights_signature'
 PUBLIC_KEY_FOLDER = pkgutil.get_data(insights.client.apps.ansible.__name__, 'playbook_verifier/public.gpg')    # Update this when we have the key generated
-VERSIONING_URL = 'https://cloud.redhat.com/api/v1/static/egg_version'
 EXCLUDABLE_VARIABLES = ['hosts', 'vars']
 
 logger = getLogger(__name__)
 
+yaml = yaml.YAML(typ='rt')
+yaml.indent(mapping=2, sequence=4, offset=2)
+yaml.default_flow_style = False
+yaml.preserve_quotes = True
+yaml.width = 200
+
 
 class PlaybookVerificationError(Exception):
     """
@@ -39,16 +42,16 @@ class PlaybookVerificationError(Exception):
         return self.message
 
 
-def eggVersioningCheck(checkVersion):
-    currentVersion = requests.get(VERSIONING_URL)
-    currentVersion = currentVersion.text
-    runningVersion = get_version_info()['core_version']
+def createSnippetHash(snippet):
+    """
+    Function that creates and returns a hash of the snippet given to the function.
+        output: snippetHash (bytes)
+    """
+    snippetHash = hashlib.sha256()
+    serializedSnippet = str(snippet).encode("UTF-8")
+    snippetHash.update(serializedSnippet)
 
-    if checkVersion:
-        if LooseVersion(currentVersion.strip()) < LooseVersion(runningVersion):
-            raise PlaybookVerificationError(message="EGG VERSION ERROR: Current running egg is not the most recent version")
-
-    return currentVersion
+    return snippetHash.digest()
 
 
 def getPublicKey(gpg):
@@ -87,7 +90,7 @@ def excludeDynamicElements(snippet):
 
 def executeVerification(snippet, encodedSignature):
     gpg = gnupg.GPG(gnupghome=constants.insights_core_lib_dir)
-    serializedSnippet = bytes(yaml.dump(snippet, default_flow_style=False).encode("UTF-8"))
+    snippetHash = createSnippetHash(snippet)
 
     decodedSignature = base64.b64decode(encodedSignature)
 
@@ -98,7 +101,7 @@ def executeVerification(snippet, encodedSignature):
     os.write(fd, decodedSignature)
     os.close(fd)
 
-    result = gpg.verify_data(fn, serializedSnippet)
+    result = gpg.verify_data(fn, snippetHash)
     os.unlink(fn)
 
     return result
@@ -106,9 +109,11 @@ def executeVerification(snippet, encodedSignature):
 
 def verifyPlaybookSnippet(snippet):
     if ('vars' not in snippet.keys()):
-        raise PlaybookVerificationError(message='VARS FIELD NOT FOUND: Verification failed')
+        raise PlaybookVerificationError(message='VERIFICATION FAILED: Vars field not found')
+    elif (snippet['vars'] is None):
+        raise PlaybookVerificationError(message='VERIFICATION FAILED: Empty vars field')
     elif (SIGKEY not in snippet['vars']):
-        raise PlaybookVerificationError(message='SIGNATURE NOT FOUND: Verification failed')
+        raise PlaybookVerificationError(message='VERIFICATION FAILED: Signature not found')
 
     encodedSignature = snippet['vars'][SIGKEY]
     snippetCopy = copy.deepcopy(snippet)
@@ -118,7 +123,7 @@ def verifyPlaybookSnippet(snippet):
     return executeVerification(snippetCopy, encodedSignature)
 
 
-def verify(playbook, checkVersion=False, skipVerify=True):
+def verify(playbook, skipVerify=True):
     """
     Verify the signed playbook.
 
@@ -128,9 +133,6 @@ def verify(playbook, checkVersion=False, skipVerify=True):
     """
     logger.info('Playbook Verification has started')
 
-    # Egg Version Check
-    eggVersioningCheck(checkVersion)
-
     if not skipVerify:
         for snippet in playbook:
             verified = verifyPlaybookSnippet(snippet)
