@@ -1,5 +1,6 @@
 import os
 import sys
+from insights.client.constants import InsightsConstants as constants
 from insights.client.apps.ansible.playbook_verifier import verify, loadPlaybookYaml
 
 
@@ -17,17 +18,14 @@ def read_playbook():
 playbook = read_playbook()
 playbook_yaml = loadPlaybookYaml(playbook)
 skipVerify = True
-checkVersion = False
 
 if (os.environ.get('SKIP_VERIFY')):
     skipVerify = False
-if (os.environ.get('CHECK_VERSION')):
-    checkVersion = True
 
 try:
-    verified_playbook = verify(playbook_yaml, checkVersion, skipVerify)
+    verified_playbook = verify(playbook_yaml, skipVerify)
 except Exception as e:
     sys.stderr.write(e.message)
-    sys.exit(1)
+    sys.exit(constants.sig_kill_bad)
 
 print(playbook)
