@@ -2,13 +2,14 @@ from glob import glob
 from insights.client.archive import InsightsArchive
 from insights.client.connection import InsightsConnection
 from insights.client.constants import InsightsConstants as constants
-from insights.client.utilities import determine_hostname
+from insights.client.utilities import os_release_info
 from logging import getLogger
-from platform import linux_distribution
 from re import findall
 from sys import exit
+import tempfile
 from insights.util.subproc import call
 import os
+import os.path
 import six
 
 NONCOMPLIANT_STATUS = 2
@@ -22,10 +23,10 @@ class ComplianceClient:
     def __init__(self, config):
         self.config = config
         self.conn = InsightsConnection(config)
-        self.hostname = determine_hostname()
         self.archive = InsightsArchive(config)
 
     def oscap_scan(self):
+        self.inventory_id = self._get_inventory_id()
         self._assert_oscap_rpms_exist()
         initial_profiles = self.get_initial_profiles()
         matching_os_profiles = self.get_profiles_matching_os()
@@ -33,13 +34,18 @@ class ComplianceClient:
         if not profiles:
             logger.error("System is not associated with any profiles. Assign profiles using the Compliance web UI.\n")
             exit(constants.sig_kill_bad)
+
+        archive_dir = self.archive.create_archive_dir()
         for profile in profiles:
+            tailoring_file = self.download_tailoring_file(profile)
             self.run_scan(
                 profile['attributes']['ref_id'],
                 self.find_scap_policy(profile['attributes']['ref_id']),
-                '/var/tmp/oscap_results-{0}.xml'.format(profile['attributes']['ref_id']),
-                tailoring_file_path=self.download_tailoring_file(profile)
+                self._results_file(archive_dir, profile),
+                tailoring_file_path=tailoring_file
             )
+            if tailoring_file:
+                os.remove(tailoring_file)
 
         return self.archive.create_tar_file(), COMPLIANCE_CONTENT_TYPE
 
@@ -52,7 +58,11 @@ class ComplianceClient:
         logger.debug(
             "Policy {0} is a tailored policy. Starting tailoring file download...".format(profile['attributes']['ref_id'])
         )
-        tailoring_file_path = "/var/tmp/oscap_tailoring_file-{0}.xml".format(profile['attributes']['ref_id'])
+        tailoring_file_path = tempfile.mkstemp(
+            prefix='oscap_tailoring_file-{0}.'.format(profile['attributes']['ref_id']),
+            suffix='.xml',
+            dir='/var/tmp'
+        )[1]
         response = self.conn.session.get(
             "https://{0}/compliance/profiles/{1}/tailoring_file".format(self.config.base_url, profile['id'])
         )
@@ -80,10 +90,10 @@ class ComplianceClient:
             return []
 
     def get_initial_profiles(self):
-        return self.get_profiles('system_names={0} canonical=false external=false'.format(self.hostname))
+        return self.get_profiles('system_ids={0} canonical=false external=false'.format(self.inventory_id))
 
     def get_profiles_matching_os(self):
-        return self.get_profiles('system_names={0} canonical=false os_minor_version={1}'.format(self.hostname, self.os_minor_version()))
+        return self.get_profiles('system_ids={0} canonical=false os_minor_version={1}'.format(self.inventory_id, self.os_minor_version()))
 
     def profile_union_by_ref_id(self, prioritized_profiles, merged_profiles):
         profiles = dict((p['attributes']['ref_id'], p) for p in merged_profiles)
@@ -92,7 +102,7 @@ class ComplianceClient:
         return list(profiles.values())
 
     def os_release(self):
-        _, version, _ = linux_distribution()
+        _, version = os_release_info()
         return version
 
     def os_major_version(self):
@@ -139,8 +149,6 @@ class ComplianceClient:
             logger.error('Scan failed')
             logger.error(oscap)
             exit(constants.sig_kill_bad)
-        else:
-            self.archive.copy_file(output_path)
 
     def _assert_oscap_rpms_exist(self):
         rpmcmd = 'rpm -qa ' + ' '.join(REQUIRED_PACKAGES)
@@ -154,3 +162,17 @@ class ComplianceClient:
             if len(rpm.strip().split('\n')) < len(REQUIRED_PACKAGES):
                 logger.error('Missing required packages for compliance scanning. Please ensure the following packages are installed: {0}\n'.format(', '.join(REQUIRED_PACKAGES)))
                 exit(constants.sig_kill_bad)
+
+    def _get_inventory_id(self):
+        systems = self.conn._fetch_system_by_machine_id()
+        if len(systems) == 1 and 'id' in systems[0]:
+            return systems[0].get('id')
+        else:
+            logger.error('Failed to find system in Inventory')
+            exit(constants.sig_kill_bad)
+
+    def _results_file(self, archive_dir, profile):
+        return os.path.join(
+            archive_dir,
+            'oscap_results-{0}.xml'.format(profile['attributes']['ref_id'])
+        )
