@@ -26,14 +26,12 @@ except ImportError:
 from .utilities import (determine_hostname,
                         generate_machine_id,
                         write_unregistered_file,
-                        write_registered_file)
+                        write_registered_file,
+                        os_release_info)
 from .cert_auth import rhsmCertificate
 from .constants import InsightsConstants as constants
 from .url_cache import URLCache
 from insights import package_info
-from insights.core.context import Context
-from insights.parsers.os_release import OsRelease
-from insights.parsers.redhat_release import RedhatRelease
 from insights.util.canonical_facts import get_canonical_facts
 
 warnings.simplefilter('ignore')
@@ -209,27 +207,7 @@ class InsightsConnection(object):
 
         python_version = "%s %s" % (platform.python_implementation(), platform.python_version())
 
-        os_family = "Unknown"
-        os_release = ""
-        for p in ["/etc/os-release", "/etc/redhat-release"]:
-            try:
-                with open(p) as f:
-                    data = f.readlines()
-
-                ctx = Context(content=data, path=p, relative_path=p)
-                if p == "/etc/os-release":
-                    rls = OsRelease(ctx)
-                    os_family = rls.data.get("NAME")
-                    os_release = rls.data.get("VERSION_ID")
-                elif p == "/etc/redhat-release":
-                    rls = RedhatRelease(ctx)
-                    os_family = rls.product
-                    os_release = rls.version
-                break
-            except IOError:
-                continue
-            except Exception as e:
-                logger.warning("Failed to detect OS version: %s", e)
+        os_family, os_release = os_release_info()
         kernel_version = "%s %s" % (platform.system(), platform.release())
 
         ua = "{client_version} ({core_version}; {requests_version}) {os_family} {os_release} ({python_version}; {kernel_version}); {parent_process}".format(
@@ -878,6 +856,9 @@ class InsightsConnection(object):
         if self.config.display_name:
             # add display_name to canonical facts
             c_facts['display_name'] = self.config.display_name
+        if self.config.ansible_host:
+            # add ansible_host to canonical facts
+            c_facts['ansible_host'] = self.config.ansible_host
         if self.config.branch_info:
             c_facts["branch_info"] = self.config.branch_info
             c_facts["satellite_id"] = self.config.branch_info["remote_leaf"]
@@ -978,6 +959,28 @@ class InsightsConnection(object):
         logger.info('Display name updated to ' + display_name + '.')
         return True
 
+    def set_ansible_host(self, ansible_host):
+        '''
+        Set Ansible hostname of a system independently of upload.
+        '''
+        system = self._fetch_system_by_machine_id()
+        if not system:
+            return system
+        inventory_id = system[0]['id']
+
+        req_url = self.inventory_url + '/hosts/' + inventory_id
+        try:
+            logger.log(NETWORK, "PATCH %s", req_url)
+            res = self.session.patch(req_url, json={'ansible_host': ansible_host})
+        except REQUEST_FAILED_EXCEPTIONS as e:
+            _api_request_failed(e)
+            return False
+        if (self.handle_fail_rcs(res)):
+            logger.error('Could not update Ansible hostname.')
+            return False
+        logger.info('Ansible hostname updated to ' + ansible_host + '.')
+        return True
+
     def get_diagnosis(self, remediation_id=None):
         '''
             Reach out to the platform and fetch a diagnosis.
