@@ -91,6 +91,12 @@ class DataCollector(object):
             self.archive.add_metadata_to_archive(
                 self.config.display_name, '/display_name')
 
+    def _write_ansible_host(self):
+        if self.config.ansible_host:
+            logger.debug("Writing ansible_host to archive...")
+            self.archive.add_metadata_to_archive(
+                self.config.ansible_host, '/ansible_host')
+
     def _write_version_info(self):
         logger.debug("Writing version information to archive...")
         version_info = get_version_info()
@@ -132,15 +138,20 @@ class DataCollector(object):
         try:
             with open(constants.egg_release_file) as fil:
                 egg_release = fil.read()
-        except IOError as e:
-            logger.debug('Could not read the egg release file :%s', str(e))
+        except (IOError, MemoryError) as e:
+            logger.debug('Could not read the egg release file: %s', str(e))
         try:
             os.remove(constants.egg_release_file)
         except OSError as e:
             logger.debug('Could not remove the egg release file: %s', str(e))
 
-        self.archive.add_metadata_to_archive(
-            egg_release, '/egg_release')
+        try:
+            self.archive.add_metadata_to_archive(
+                egg_release, '/egg_release')
+        except OSError as e:
+            logger.debug('Could not add the egg release file to the archive: %s', str(e))
+            self.archive.add_metadata_to_archive(
+                '', '/egg_release')
 
     def _write_collection_stats(self, collection_stats):
         logger.debug("Writing collection stats to archive...")
@@ -324,6 +335,7 @@ class DataCollector(object):
         logger.debug('Collecting metadata...')
         self._write_branch_info(branch_info)
         self._write_display_name()
+        self._write_ansible_host()
         self._write_version_info()
         self._write_tags()
         self._write_blacklist_report(blacklist_report)
