@@ -275,6 +275,14 @@ def post_update(client, config):
         else:
             sys.exit(constants.sig_kill_bad)
 
+    # set --ansible-hostname independent of register
+    # only do this if set from the CLI. normally display_name is sent on upload
+    if 'ansible_host' in config._cli_opts and not config.register:
+        if client.set_ansible_host(config.ansible_host):
+            sys.exit(constants.sig_kill_ok)
+        else:
+            sys.exit(constants.sig_kill_bad)
+
 
 @phase
 def collect_and_output(client, config):
