@@ -10,7 +10,8 @@ from insights.specs import Specs
 
 _green = "Boot Status is GREEN"
 _red = "Boot Status is RED"
-add_filter(Specs.greenboot_status, [_green, _red])
+_fallback = "FALLBACK BOOT DETECTED"
+add_filter(Specs.greenboot_status, [_green, _red, _fallback])
 
 
 @parser(Specs.greenboot_status)
@@ -31,3 +32,4 @@ class GreenbootStatus(LogFileOutput):
 
 GreenbootStatus.token_scan("green", _green)
 GreenbootStatus.token_scan("red", _red)
+GreenbootStatus.token_scan("fallback", _fallback)
