@@ -1,24 +1,11 @@
 from insights.core.spec_factory import SpecSet, RegistryPoint
 
 
-class Openshift(SpecSet):
-    cluster_operators = RegistryPoint(raw=True)
-    crds = RegistryPoint(raw=True)
-    crs = RegistryPoint(raw=True, multi_output=True)
-    machine_configs = RegistryPoint(raw=True)
-    machines = RegistryPoint(raw=True)
-    machine_id = RegistryPoint(raw=True)  # stand in for system id
-    namespaces = RegistryPoint(raw=True)
-    nodes = RegistryPoint(raw=True)
-    pods = RegistryPoint(raw=True)
-    pvcs = RegistryPoint(raw=True)
-    storage_classes = RegistryPoint(raw=True)
-
-
 class Specs(SpecSet):
     abrt_ccpp_conf = RegistryPoint(filterable=True)
     abrt_status_bare = RegistryPoint()
     alternatives_display_python = RegistryPoint()
+    ansible_tower_settings = RegistryPoint(filterable=True, multi_output=True)
     amq_broker = RegistryPoint(multi_output=True)
     ansible_host = RegistryPoint()
     auditctl_status = RegistryPoint()
@@ -40,6 +27,7 @@ class Specs(SpecSet):
     boot_loader_entries = RegistryPoint(multi_output=True)
     branch_info = RegistryPoint(raw=True)
     brctl_show = RegistryPoint()
+    candlepin_broker = RegistryPoint()
     candlepin_error_log = RegistryPoint(filterable=True)
     candlepin_log = RegistryPoint(filterable=True)
     cdc_wdm = RegistryPoint()
@@ -187,6 +175,7 @@ class Specs(SpecSet):
     freeipa_healthcheck_log = RegistryPoint()
     fstab = RegistryPoint()
     galera_cnf = RegistryPoint()
+    gcp_instance_type = RegistryPoint()
     gcp_license_codes = RegistryPoint()
     getcert_list = RegistryPoint()
     getconf_page_size = RegistryPoint()
@@ -359,6 +348,7 @@ class Specs(SpecSet):
     meminfo = RegistryPoint()
     messages = RegistryPoint(filterable=True)
     metadata_json = RegistryPoint(raw=True)
+    satellite_missed_pulp_agent_queues = RegistryPoint()
     mistral_executor_log = RegistryPoint(filterable=True)
     mlx4_port = RegistryPoint(multi_output=True)
     modinfo_i40e = RegistryPoint()
@@ -473,7 +463,7 @@ class Specs(SpecSet):
     ovs_vsctl_show = RegistryPoint()
     ovs_vswitchd_limits = RegistryPoint()
     pacemaker_log = RegistryPoint(filterable=True)
-    package_provides_command = RegistryPoint()
+    package_provides_command = RegistryPoint(filterable=True)
     package_provides_java = RegistryPoint(multi_output=True)
     package_provides_httpd = RegistryPoint(multi_output=True)
     pam_conf = RegistryPoint()
@@ -510,6 +500,7 @@ class Specs(SpecSet):
     ps_auxww = RegistryPoint(filterable=True)
     ps_ef = RegistryPoint(filterable=True)
     ps_eo = RegistryPoint()
+    ps_eo_cmd = RegistryPoint()
     pulp_worker_defaults = RegistryPoint()
     puppet_ssl_cert_ca_pem = RegistryPoint()
     puppetserver_config = RegistryPoint(filterable=True)
@@ -559,6 +550,7 @@ class Specs(SpecSet):
     rndc_status = RegistryPoint()
     root_crontab = RegistryPoint()
     route = RegistryPoint()
+    rpm_ostree_status = RegistryPoint()
     rpm_V_packages = RegistryPoint()
     rsyslog_conf = RegistryPoint(filterable=True, multi_output=True)
     samba = RegistryPoint(filterable=True)
@@ -624,6 +616,7 @@ class Specs(SpecSet):
     swift_proxy_server_conf = RegistryPoint()
     sys_kernel_sched_features = RegistryPoint()
     sysconfig_chronyd = RegistryPoint()
+    sysconfig_grub = RegistryPoint()
     sysconfig_httpd = RegistryPoint()
     sysconfig_irqbalance = RegistryPoint()
     sysconfig_kdump = RegistryPoint()
@@ -661,6 +654,8 @@ class Specs(SpecSet):
     systemd_system_origin_accounting = RegistryPoint()
     systemid = RegistryPoint()
     systool_b_scsi_v = RegistryPoint()
+    sys_vmbus_device_id = RegistryPoint(multi_output=True)
+    sys_vmbus_class_id = RegistryPoint(multi_output=True)
     testparm_s = RegistryPoint(filterable=True)
     testparm_v_s = RegistryPoint(filterable=True)
     tags = RegistryPoint()
