@@ -8,37 +8,38 @@ this file with the same `name` keyword argument. This allows overriding the
 data sources that standard Insights `Parsers` resolve against.
 """
 
+import datetime
 import logging
 import os
 import re
-import json
 import signal
 
 from grp import getgrgid
 from os import stat
 from pwd import getpwuid
 
-import yaml
-
 from insights.core.context import HostContext
 from insights.core.dr import SkipComponent
 from insights.core.plugins import datasource
-from insights.core.spec_factory import RawFileProvider, DatasourceProvider
+from insights.core.spec_factory import RawFileProvider
 from insights.core.spec_factory import simple_file, simple_command, glob_file
 from insights.core.spec_factory import first_of, command_with_args
 from insights.core.spec_factory import foreach_collect, foreach_execute
 from insights.core.spec_factory import first_file, listdir
-from insights.combiners.cloud_provider import CloudProvider
 from insights.combiners.services import Services
-from insights.combiners.sap import Sap
 from insights.combiners.ps import Ps
 from insights.components.rhel_version import IsRhel8, IsRhel7, IsRhel6
+from insights.components.cloud_provider import IsAWS, IsAzure, IsGCP
+from insights.components.ceph import IsCephMonitor
 from insights.parsers.mdstat import Mdstat
 from insights.parsers.lsmod import LsMod
 from insights.combiners.satellite_version import SatelliteVersion, CapsuleVersion
 from insights.parsers.mount import Mount
 from insights.specs import Specs
-import datetime
+from insights.specs.datasources import (
+    cloud_init, candlepin_broker, ethernet, get_running_commands, ipcs, package_provides,
+    ps as ps_datasource, sap, satellite_missed_queues)
+from insights.specs.datasources.sap import sap_hana_sid, sap_hana_sid_SID_nr
 
 
 logger = logging.getLogger(__name__)
@@ -52,55 +53,6 @@ def get_owner(filename):
     return (name, group)
 
 
-def _get_running_commands(broker, commands):
-    """
-    Search for command in ``ps auxcww`` output and determine RPM providing binary
-
-    Arguments:
-        broker(dict): Current state of specs collected by Insights
-        commands(str or list): Command or list of commands to search for in ps output
-
-    Returns:
-        list: List of the full command paths of the ``command``.
-
-    Raises:
-        Exception: Raises an exception if commands object is not a list or is empty
-    """
-    if not commands or not isinstance(commands, list):
-        raise Exception('Commands argument must be a list object and contain at least one item')
-
-    ps_list = [broker[Ps].search(COMMAND_NAME__contains=c) for c in commands]
-    ps_cmds = [i for sub_l in ps_list for i in sub_l]
-    ctx = broker[HostContext]
-
-    ret = set()
-    for cmd in set(p['COMMAND_NAME'] for p in ps_cmds):
-        try:
-            which = ctx.shell_out("/usr/bin/which {0}".format(cmd))
-        except Exception:
-            continue
-        ret.add(which[0]) if which else None
-    return sorted(ret)
-
-
-def _get_package(broker, command):
-    """
-    Arguments:
-        broker(dict): Current state of specs collected by Insights
-        command(str): The full command name to get the package
-
-    Returns:
-        str: The package that provides the ``command``.
-    """
-    ctx = broker[HostContext]
-    resolved = ctx.shell_out("/usr/bin/readlink -e {0}".format(command))
-    if resolved:
-        pkg = ctx.shell_out("/usr/bin/rpm -qf {0}".format(resolved[0]), signum=signal.SIGTERM)
-        if pkg:
-            return pkg[0]
-    raise SkipComponent
-
-
 def _make_rpm_formatter(fmt=None):
     """ function: Returns function that will format output of rpm query command """
     if fmt is None:
@@ -133,34 +85,17 @@ class DefaultSpecs(Specs):
     abrt_status_bare = simple_command("/usr/bin/abrt status --bare=True")
     alternatives_display_python = simple_command("/usr/sbin/alternatives --display python")
     amq_broker = glob_file("/var/opt/amq-broker/*/etc/broker.xml")
+    ansible_tower_settings = glob_file(["/etc/tower/settings.py", "/etc/tower/conf.d/*.py"])
     auditctl_status = simple_command("/sbin/auditctl -s")
     auditd_conf = simple_file("/etc/audit/auditd.conf")
     audit_log = simple_file("/var/log/audit/audit.log")
     avc_hash_stats = simple_file("/sys/fs/selinux/avc/hash_stats")
     avc_cache_threshold = simple_file("/sys/fs/selinux/avc/cache_threshold")
-
-    @datasource(CloudProvider, HostContext)
-    def is_aws(broker):
-        """ bool: Returns True if this node is identified as running in AWS """
-        cp = broker[CloudProvider]
-        if cp and cp.cloud_provider == CloudProvider.AWS:
-            return True
-        raise SkipComponent()
-
-    aws_instance_id_doc = simple_command("/usr/bin/curl -s http://169.254.169.254/latest/dynamic/instance-identity/document --connect-timeout 5", deps=[is_aws])
-    aws_instance_id_pkcs7 = simple_command("/usr/bin/curl -s http://169.254.169.254/latest/dynamic/instance-identity/pkcs7 --connect-timeout 5", deps=[is_aws])
+    aws_instance_id_doc = simple_command("/usr/bin/curl -s http://169.254.169.254/latest/dynamic/instance-identity/document --connect-timeout 5", deps=[IsAWS])
+    aws_instance_id_pkcs7 = simple_command("/usr/bin/curl -s http://169.254.169.254/latest/dynamic/instance-identity/pkcs7 --connect-timeout 5", deps=[IsAWS])
     awx_manage_check_license = simple_command("/usr/bin/awx-manage check_license")
-
-    @datasource(CloudProvider, HostContext)
-    def is_azure(broker):
-        """ bool: Returns True if this node is identified as running in Azure """
-        cp = broker[CloudProvider]
-        if cp and cp.cloud_provider == CloudProvider.AZURE:
-            return True
-        raise SkipComponent()
-
-    azure_instance_type = simple_command("/usr/bin/curl -s -H Metadata:true http://169.254.169.254/metadata/instance/compute/vmSize?api-version=2018-10-01&format=text --connect-timeout 5", deps=[is_azure])
-    azure_instance_plan = simple_command("/usr/bin/curl -s -H Metadata:true http://169.254.169.254/metadata/instance/compute/plan?api-version=2018-10-01&format=json --connect-timeout 5", deps=[is_azure])
+    azure_instance_type = simple_command("/usr/bin/curl -s -H Metadata:true http://169.254.169.254/metadata/instance/compute/vmSize?api-version=2018-10-01&format=text --connect-timeout 5", deps=[IsAzure])
+    azure_instance_plan = simple_command("/usr/bin/curl -s -H Metadata:true http://169.254.169.254/metadata/instance/compute/plan?api-version=2018-10-01&format=json --connect-timeout 5", deps=[IsAzure])
     bios_uuid = simple_command("/usr/sbin/dmidecode -s system-uuid")
     blkid = simple_command("/sbin/blkid -c /dev/null")
     bond = glob_file("/proc/net/bonding/bond*")
@@ -168,6 +103,7 @@ class DefaultSpecs(Specs):
     boot_loader_entries = glob_file("/boot/loader/entries/*.conf")
     branch_info = simple_file("/branch_info", kind=RawFileProvider)
     brctl_show = simple_command("/usr/sbin/brctl show")
+    candlepin_broker = candlepin_broker.candlepin_broker
     candlepin_log = simple_file("/var/log/candlepin/candlepin.log")
     cgroups = simple_file("/proc/cgroups")
     ps_alxwww = simple_command("/bin/ps alxwww")
@@ -176,6 +112,7 @@ class DefaultSpecs(Specs):
     ps_auxww = simple_command("/bin/ps auxww")
     ps_ef = simple_command("/bin/ps -ef")
     ps_eo = simple_command("/usr/bin/ps -eo pid,ppid,comm")
+    ps_eo_cmd = ps_datasource.ps_eo_cmd
 
     @datasource(ps_auxww, HostContext)
     def tomcat_base(broker):
@@ -205,16 +142,7 @@ class DefaultSpecs(Specs):
     ceph_conf = first_file(["/var/lib/config-data/puppet-generated/ceph/etc/ceph/ceph.conf", "/etc/ceph/ceph.conf"])
     ceph_df_detail = simple_command("/usr/bin/ceph df detail -f json")
     ceph_health_detail = simple_command("/usr/bin/ceph health detail -f json")
-
-    @datasource(Ps, HostContext)
-    def is_ceph_monitor(broker):
-        """ bool: Returns True if ceph monitor process ceph-mon is running on this node """
-        ps = broker[Ps]
-        if ps.search(COMMAND__contains='ceph-mon'):
-            return True
-        raise SkipComponent()
-
-    ceph_insights = simple_command("/usr/bin/ceph insights", deps=[is_ceph_monitor])
+    ceph_insights = simple_command("/usr/bin/ceph insights", deps=[IsCephMonitor])
     ceph_log = glob_file(r"var/log/ceph/ceph.log*")
     ceph_osd_dump = simple_command("/usr/bin/ceph osd dump -f json")
     ceph_osd_ec_profile_ls = simple_command("/usr/bin/ceph osd erasure-code-profile ls")
@@ -230,70 +158,7 @@ class DefaultSpecs(Specs):
     cinder_api_log = first_file(["/var/log/containers/cinder/cinder-api.log", "/var/log/cinder/cinder-api.log"])
     cinder_conf = first_file(["/var/lib/config-data/puppet-generated/cinder/etc/cinder/cinder.conf", "/etc/cinder/cinder.conf"])
     cinder_volume_log = first_file(["/var/log/containers/cinder/volume.log", "/var/log/containers/cinder/cinder-volume.log", "/var/log/cinder/volume.log"])
-    cloud_cfg_input = simple_file("/etc/cloud/cloud.cfg")
-
-    @datasource(cloud_cfg_input, HostContext)
-    def cloud_cfg(broker):
-        """This datasource provides the network configuration collected
-        from ``/etc/cloud/cloud.cfg``.
-
-        Typical content of ``/etc/cloud/cloud.cfg`` file is::
-
-            #cloud-config
-            users:
-              - name: demo
-                ssh-authorized-keys:
-                  - key_one
-                  - key_two
-                passwd: $6$j212wezy$7H/1LT4f9/N3wpgNunhsIqtMj62OKiS3nyNwuizouQc3u7MbYCarYeAHWYPYb2FT.lbioDm2RrkJPb9BZMN1O/
-
-            network:
-              version: 1
-              config:
-                - type: physical
-                  name: eth0
-                  subnets:
-                    - type: dhcp
-                    - type: dhcp6
-
-            system_info:
-              default_user:
-                name: user2
-                plain_text_passwd: 'someP@assword'
-                home: /home/user2
-
-            debug:
-              output: /var/log/cloud-init-debug.log
-              verbose: true
-
-        Note:
-            This datasource may be executed using the following command:
-
-            ``insights-cat --no-header cloud_cfg``
-
-        Example:
-
-            ``{"version": 1, "config": [{"type": "physical", "name": "eth0", "subnets": [{"type": "dhcp"}, {"type": "dhcp6"}]}]}``
-
-        Returns:
-            str: JSON string when the ``network`` parameter is configure, else nothing is returned.
-
-        Raises:
-            SkipComponent: When the path does not exist or any exception occurs.
-        """
-        relative_path = '/etc/cloud/cloud.cfg'
-        try:
-            content = broker[DefaultSpecs.cloud_cfg_input].content
-            if content:
-                content = yaml.load('\n'.join(content), Loader=yaml.SafeLoader)
-                network_config = content.get('network', None)
-                if network_config:
-                    return DatasourceProvider(content=json.dumps(network_config), relative_path=relative_path)
-        except Exception as e:
-            raise SkipComponent("Unexpected exception:{e}".format(e=str(e)))
-
-        raise SkipComponent()
-
+    cloud_cfg = cloud_init.cloud_cfg
     cloud_init_custom_network = simple_file("/etc/cloud/cloud.cfg.d/99-custom-networking.cfg")
     cloud_init_log = simple_file("/var/log/cloud-init.log")
     cluster_conf = simple_file("/etc/cluster/cluster.conf")
@@ -380,13 +245,13 @@ class DefaultSpecs(Specs):
                                        "/usr/lib/udev/rules.d/40-redhat.rules", "/usr/local/lib/udev/rules.d/40-redhat.rules"])
     etcd_conf = simple_file("/etc/etcd/etcd.conf")
     ethernet_interfaces = listdir("/sys/class/net", context=HostContext)
-    ethtool = foreach_execute(ethernet_interfaces, "/sbin/ethtool %s")
-    ethtool_S = foreach_execute(ethernet_interfaces, "/sbin/ethtool -S %s")
-    ethtool_T = foreach_execute(ethernet_interfaces, "/sbin/ethtool -T %s")
-    ethtool_c = foreach_execute(ethernet_interfaces, "/sbin/ethtool -c %s")
-    ethtool_g = foreach_execute(ethernet_interfaces, "/sbin/ethtool -g %s")
-    ethtool_i = foreach_execute(ethernet_interfaces, "/sbin/ethtool -i %s")
-    ethtool_k = foreach_execute(ethernet_interfaces, "/sbin/ethtool -k %s")
+    ethtool = foreach_execute(ethernet.interfaces, "/sbin/ethtool %s")
+    ethtool_S = foreach_execute(ethernet.interfaces, "/sbin/ethtool -S %s")
+    ethtool_T = foreach_execute(ethernet.interfaces, "/sbin/ethtool -T %s")
+    ethtool_c = foreach_execute(ethernet.interfaces, "/sbin/ethtool -c %s")
+    ethtool_g = foreach_execute(ethernet.interfaces, "/sbin/ethtool -g %s")
+    ethtool_i = foreach_execute(ethernet.interfaces, "/sbin/ethtool -i %s")
+    ethtool_k = foreach_execute(ethernet.interfaces, "/sbin/ethtool -k %s")
     facter = simple_command("/usr/bin/facter")
     fc_match = simple_command("/bin/fc-match -sv 'sans:regular:roman' family fontformat")
     fcoeadm_i = simple_command("/usr/sbin/fcoeadm -i")
@@ -424,16 +289,8 @@ class DefaultSpecs(Specs):
     gluster_v_info = simple_command("/usr/sbin/gluster volume info")
     gnocchi_conf = first_file(["/var/lib/config-data/puppet-generated/gnocchi/etc/gnocchi/gnocchi.conf", "/etc/gnocchi/gnocchi.conf"])
     gnocchi_metricd_log = first_file(["/var/log/containers/gnocchi/gnocchi-metricd.log", "/var/log/gnocchi/metricd.log"])
-
-    @datasource(CloudProvider, HostContext)
-    def is_gcp(broker):
-        """ bool: Returns True if this node is identified as running in GCP """
-        cp = broker[CloudProvider]
-        if cp and cp.cloud_provider == CloudProvider.GOOGLE:
-            return True
-        raise SkipComponent()
-
-    gcp_license_codes = simple_command("/usr/bin/curl -s curl -H Metadata-Flavor: Google http://metadata.google.internal/computeMetadata/v1/instance/licenses/?recursive=True --connect-timeout 5", deps=[is_gcp])
+    gcp_instance_type = simple_command("/usr/bin/curl -s -H 'Metadata-Flavor: Google' http://metadata.google.internal/computeMetadata/v1/instance/machine-type --connect-timeout 5", deps=[IsGCP])
+    gcp_license_codes = simple_command("/usr/bin/curl -s -H 'Metadata-Flavor: Google' http://metadata.google.internal/computeMetadata/v1/instance/licenses/?recursive=True --connect-timeout 5", deps=[IsGCP])
     greenboot_status = simple_command("/usr/libexec/greenboot/greenboot-status")
     grub_conf = simple_file("/boot/grub/grub.conf")
     grub_config_perms = simple_command("/bin/ls -l /boot/grub2/grub.cfg")  # only RHEL7 and updwards
@@ -489,7 +346,7 @@ class DefaultSpecs(Specs):
         Returns:
             list: List of the binary paths to each running process
         """
-        return _get_running_commands(broker, ['httpd', ])
+        return get_running_commands(broker[Ps], broker[HostContext], ['httpd', ])
 
     httpd_pid = simple_command("/usr/bin/pgrep -o httpd")
     httpd_limits = foreach_collect(httpd_pid, "/proc/%s/limits")
@@ -510,6 +367,7 @@ class DefaultSpecs(Specs):
     ipcs_m = simple_command("/usr/bin/ipcs -m")
     ipcs_m_p = simple_command("/usr/bin/ipcs -m -p")
     ipcs_s = simple_command("/usr/bin/ipcs -s")
+    ipcs_s_i = foreach_execute(ipcs.semid, "/usr/bin/ipcs -s -i %s")
     ipsec_conf = simple_file("/etc/ipsec.conf")
     iptables = simple_command("/sbin/iptables-save")
     iptables_permanent = simple_file("etc/sysconfig/iptables")
@@ -528,6 +386,7 @@ class DefaultSpecs(Specs):
     kubepods_cpu_quota = glob_file("/sys/fs/cgroup/cpu/kubepods.slice/kubepods-burstable.slice/kubepods-burstable-pod[a-f0-9_]*.slice/cpu.cfs_quota_us")
     last_upload_globs = ["/etc/redhat-access-insights/.lastupload", "/etc/insights-client/.lastupload"]
     lastupload = glob_file(last_upload_globs)
+    ld_library_path_of_user = sap.ld_library_path_of_user
     libssh_client_config = simple_file("/etc/libssh/libssh_client.config")
     libssh_server_config = simple_file("/etc/libssh/libssh_server.config")
     libvirtd_log = simple_file("/var/log/libvirt/libvirtd.log")
@@ -605,11 +464,9 @@ class DefaultSpecs(Specs):
     modprobe = glob_file(["/etc/modprobe.conf", "/etc/modprobe.d/*.conf"])
     mokutil_sbstate = simple_command("/bin/mokutil --sb-state")
     mongod_conf = glob_file([
-                            "/etc/mongod.conf",
-                            "/etc/mongodb.conf",
-                            "/etc/opt/rh/rh-mongodb26/mongod.conf",
-                            "/etc/opt/rh/rh-mongodb34/mongod.conf"
-                            ])
+        "/etc/mongod.conf",
+        "/etc/opt/rh/rh-mongodb34/mongod.conf"
+    ])
     mount = simple_command("/bin/mount")
     mounts = simple_file("/proc/mounts")
     mssql_conf = simple_file("/var/opt/mssql/mssql.conf")
@@ -688,27 +545,9 @@ class DefaultSpecs(Specs):
     ovirt_engine_ui_log = simple_file("/var/log/ovirt-engine/ui.log")
     ovs_vsctl_list_bridge = simple_command("/usr/bin/ovs-vsctl list bridge")
     ovs_vsctl_show = simple_command("/usr/bin/ovs-vsctl show")
-
-    @datasource(Ps, HostContext)
-    def cmd_and_pkg(broker):
-        """
-        Returns:
-            list: List of the command and provider package string of the specified commands.
-
-        Attributes:
-            COMMANDS (list): List of the specified commands that need to check the provider package.
-        """
-        COMMANDS = ['java']
-        pkg_cmd = list()
-        for cmd in _get_running_commands(broker, COMMANDS):
-            pkg_cmd.append("{0} {1}".format(cmd, _get_package(broker, cmd)))
-        if pkg_cmd:
-            return '\n'.join(pkg_cmd)
-        raise SkipComponent
-
-    package_provides_command = command_with_args("/usr/bin/echo '%s'", cmd_and_pkg)
-    package_provides_java = foreach_execute(cmd_and_pkg, "/usr/bin/echo '%s'")
+    package_provides_command = package_provides.cmd_and_pkg
     pacemaker_log = first_file(["/var/log/pacemaker.log", "/var/log/pacemaker/pacemaker.log"])
+    partitions = simple_file("/proc/partitions")
     pci_rport_target_disk_paths = simple_command("/usr/bin/find /sys/devices/ -maxdepth 10 -mindepth 9 -name stat -type f")
 
     @datasource(Services, HostContext)
@@ -755,7 +594,7 @@ class DefaultSpecs(Specs):
     pmlog_summary = command_with_args(
         "/usr/bin/pmlogsummary %s mem.util.used mem.physmem kernel.all.cpu.user kernel.all.cpu.sys kernel.all.cpu.nice kernel.all.cpu.steal kernel.all.cpu.idle disk.all.total mem.util.cached mem.util.bufmem mem.util.free kernel.all.cpu.wait.total",
         pmlog_summary_file)
-    pmrep_metrics = simple_command("pmrep -t 1s -T 1s network.interface.out.packets network.interface.collisions swap.pagesout -o csv")
+    pmrep_metrics = simple_command("/usr/bin/pmrep -t 1s -T 1s network.interface.out.packets network.interface.collisions swap.pagesout mssql.memory_manager.stolen_server_memory mssql.memory_manager.total_server_memory -o csv")
     postconf_builtin = simple_command("/usr/sbin/postconf -C builtin")
     postconf = simple_command("/usr/sbin/postconf")
     postgresql_conf = first_file([
@@ -797,115 +636,36 @@ class DefaultSpecs(Specs):
     rhsm_log = simple_file("/var/log/rhsm/rhsm.log")
     rhsm_releasever = simple_file('/var/lib/rhsm/cache/releasever.json')
     rndc_status = simple_command("/usr/sbin/rndc status")
+    rpm_ostree_status = simple_command("/usr/bin/rpm-ostree status --json")
     rpm_V_packages = simple_command("/bin/rpm -V coreutils procps procps-ng shadow-utils passwd sudo chrony", keep_rc=True, signum=signal.SIGTERM)
     rsyslog_conf = glob_file(["/etc/rsyslog.conf", "/etc/rsyslog.d/*.conf"])
     samba = simple_file("/etc/samba/smb.conf")
-
-    @datasource(Sap, HostContext)
-    def sap_instance(broker):
-        """
-        list: List of all SAP Instances.
-        """
-        sap = broker[Sap]
-        return list(v for v in sap.values())
-
-    @datasource(sap_instance, HostContext)
-    def sap_hana_instance(broker):
-        """
-        list: List of the SAP HANA Instances.
-        """
-        sap = broker[DefaultSpecs.sap_instance]
-        return list(v for v in sap if v.type == 'HDB')
-
-    @datasource(sap_instance, HostContext)
-    def sap_sid(broker):
-        """
-        list: List of the SID of all the SAP Instances.
-        """
-        sap = broker[DefaultSpecs.sap_instance]
-        return list(set(h.sid.lower() for h in sap))
-
-    @datasource(sap_hana_instance, HostContext)
-    def sap_hana_sid(broker):
-        """
-        list: List of the SID of SAP HANA Instances.
-        """
-        hana = broker[DefaultSpecs.sap_hana_instance]
-        return list(set(h.sid.lower() for h in hana))
-
-    @datasource(sap_hana_instance, HostContext)
-    def sap_hana_sid_SID_nr(broker):
-        """
-        list: List of tuples (sid, SID, Nr) of SAP HANA Instances.
-        """
-        hana = broker[DefaultSpecs.sap_hana_instance]
-        return list((h.sid.lower(), h.sid, h.number) for h in hana)
-
-    @datasource(sap_sid, HostContext)
-    def ld_library_path_of_user(broker):
-        """
-        Returns: The list of LD_LIBRARY_PATH of specified users.
-                 Username is combined from SAP <SID> and 'adm' and is also stored.
-        """
-        sids = broker[DefaultSpecs.sap_sid]
-        ctx = broker[HostContext]
-        llds = []
-        for sid in sids:
-            usr = '{0}adm'.format(sid)
-            ret, vvs = ctx.shell_out("/bin/su -l {0} -c /bin/env".format(usr), keep_rc=True)
-            if ret != 0:
-                continue
-            for v in vvs:
-                if "LD_LIBRARY_PATH=" in v:
-                    llds.append('{0} {1}'.format(usr, v.split('=', 1)[-1]))
-        if llds:
-            return DatasourceProvider('\n'.join(llds), relative_path='insights_commands/echo_user_LD_LIBRARY_PATH')
-        raise SkipComponent
-
     sap_hana_landscape = foreach_execute(sap_hana_sid_SID_nr, "/bin/su -l %sadm -c 'python /usr/sap/%s/HDB%s/exe/python_support/landscapeHostConfiguration.py'", keep_rc=True)
     sap_hdb_version = foreach_execute(sap_hana_sid, "/bin/su -l %sadm -c 'HDB version'", keep_rc=True)
     saphostctl_getcimobject_sapinstance = simple_command("/usr/sap/hostctrl/exe/saphostctrl -function GetCIMObject -enuminstances SAPInstance")
     saphostexec_status = simple_command("/usr/sap/hostctrl/exe/saphostexec -status")
     saphostexec_version = simple_command("/usr/sap/hostctrl/exe/saphostexec -version")
     sat5_insights_properties = simple_file("/etc/redhat-access/redhat-access-insights.properties")
-
-    @datasource(SatelliteVersion, HostContext)
-    def is_satellite_server(broker):
-        """
-        bool: Returns True if the host is satellite server.
-        """
-        if broker[SatelliteVersion]:
-            return True
-        raise SkipComponent
-
-    @datasource(CapsuleVersion, HostContext)
-    def is_satellite_capsule(broker):
-        """
-        bool: Returns True if the host is satellite capsule.
-        """
-        if broker[CapsuleVersion]:
-            return True
-        raise SkipComponent
-
     satellite_compute_resources = simple_command(
         "/usr/bin/sudo -iu postgres /usr/bin/psql -d foreman -c 'select name, type from compute_resources' --csv",
-        deps=[is_satellite_server]
+        deps=[SatelliteVersion]
     )
     satellite_content_hosts_count = simple_command(
         "/usr/bin/sudo -iu postgres /usr/bin/psql -d foreman -c 'select count(*) from hosts'",
-        deps=[is_satellite_server]
+        deps=[SatelliteVersion]
     )
     satellite_custom_ca_chain = simple_command(
         '/usr/bin/awk \'BEGIN { pipe="openssl x509 -noout -subject -enddate"} /^-+BEGIN CERT/,/^-+END CERT/ { print | pipe } /^-+END CERT/ { close(pipe); printf("\\n")}\' /etc/pki/katello/certs/katello-server-ca.crt',
     )
+    satellite_missed_pulp_agent_queues = satellite_missed_queues.satellite_missed_pulp_agent_queues
     satellite_mongodb_storage_engine = simple_command("/usr/bin/mongo pulp_database --eval 'db.serverStatus().storageEngine'")
     satellite_non_yum_type_repos = simple_command(
         "/usr/bin/mongo pulp_database --eval 'db.repo_importers.find({\"importer_type_id\": { $ne: \"yum_importer\"}}).count()'",
-        deps=[[is_satellite_server, is_satellite_capsule]]
+        deps=[[SatelliteVersion, CapsuleVersion]]
     )
     satellite_settings = simple_command(
         "/usr/bin/sudo -iu postgres /usr/bin/psql -d foreman -c \"select name, value, \\\"default\\\" from settings where name in ('destroy_vm_on_host_delete', 'unregister_delete_host')\" --csv",
-        deps=[is_satellite_server]
+        deps=[SatelliteVersion]
     )
     satellite_version_rb = simple_file("/usr/share/foreman/lib/satellite/version.rb")
     satellite_custom_hiera = simple_file("/etc/foreman-installer/custom-hiera.yaml")
@@ -951,6 +711,7 @@ class DefaultSpecs(Specs):
     subscription_manager_installed_product_ids = simple_command("/usr/bin/find /etc/pki/product-default/ /etc/pki/product/ -name '*pem' -exec rct cat-cert --no-content '{}' \;")
     swift_object_expirer_conf = first_file(["/var/lib/config-data/puppet-generated/swift/etc/swift/object-expirer.conf", "/etc/swift/object-expirer.conf"])
     swift_proxy_server_conf = first_file(["/var/lib/config-data/puppet-generated/swift/etc/swift/proxy-server.conf", "/etc/swift/proxy-server.conf"])
+    sysconfig_grub = simple_file("/etc/default/grub")  # This is the file where the "/etc/sysconfig/grub" point to
     sysconfig_kdump = simple_file("etc/sysconfig/kdump")
     sysconfig_libvirt_guests = simple_file("etc/sysconfig/libvirt-guests")
     sysconfig_network = simple_file("etc/sysconfig/network")
@@ -982,6 +743,8 @@ class DefaultSpecs(Specs):
         simple_file("/conf/rhn/sysconfig/rhn/systemid")
     ])
     systool_b_scsi_v = simple_command("/bin/systool -b scsi -v")
+    sys_vmbus_device_id = glob_file('/sys/bus/vmbus/devices/*/device_id')
+    sys_vmbus_class_id = glob_file('/sys/bus/vmbus/devices/*/class_id')
     testparm_s = simple_command("/usr/bin/testparm -s")
     testparm_v_s = simple_command("/usr/bin/testparm -v -s")
     tags = simple_file("/tags.json", kind=RawFileProvider)
@@ -1008,6 +771,7 @@ class DefaultSpecs(Specs):
     virt_what = simple_command("/usr/sbin/virt-what")
     virt_who_conf = glob_file([r"etc/virt-who.conf", r"etc/virt-who.d/*.conf"])
     virtlogd_conf = simple_file("/etc/libvirt/virtlogd.conf")
+    vmware_tools_conf = simple_file("/etc/vmware-tools/tools.conf")
     vsftpd = simple_file("/etc/pam.d/vsftpd")
     vsftpd_conf = simple_file("/etc/vsftpd/vsftpd.conf")
     x86_pti_enabled = simple_file("sys/kernel/debug/x86/pti_enabled")
